==> saods9_3.0.3.orig.tar.gz: saods9/saotk/panner/panner.h <==
// Copyright (C) 1999-2004
// Smithsonian Astrophysical Observatory, Cambridge, MA, USA
// For conditions of distribution and use, see copyright notice in "copyright"

#ifndef __panner_h__
#define __panner_h__

#include "widget.h"

class Panner : public Widget {
private:
  Pixmap thumbnail;          // current frame thumbnail pixmap
  BBox bbox;                 // current view
  int highLite;              // flag to highlite bbox
  int panning;               // flag for panning status
  Vector panStart;           // initial location of panning operation
  Rotate imageCompass;       // compass orientation matrix
  Vector wcsNorth;           // wcs north unit vector
  Vector wcsEast;            // wcs east unit vector
  int useBBox;               // flag to use BBox
  int useImageCompass;       // flag to use image compass
  int useWCSCompass;         // flag to use wcs compass
  int validWCSCompass;       // flag to indicate wcs data is valid
  int useFont;               // flag to use fonts
  int needsUpdate;           // flag to indicate refresh needed

  Tk_Font font;              // Tk font
  Tk_FontMetrics metric;     // Tk font metric
				  
  GC bboxGC;                 // bbox gc
  GC compassGC;              // compass gc

  void update();             // use existing pixmap, just update
  void invalidPixmap();      // new pixmap, then update

protected:
  virtual void clearPixmap() =0;  // clear pixmap

private:
  int updatePixmap(const BBox&); // renders image/graphics into pixmap
  void renderBBox();
  void renderImageCompass();
  void renderWCSCompass();
  void renderArm(int, Vector&, Rotate&, char*, int);
  void updateGCs();

public:
  Panner(Tcl_Interp*, Tk_Canvas, Tk_Item*);
  virtual ~Panner();

#if __GNUC__ >= 3
  int parse(istringstream&);            // parse subcommands
#else
  int parse(istrstream&);            // parse subcommands
#endif

  // SubCommandFunctions

  void getBBoxCmd();
  void getSizeCmd();
  void highLiteCmd(int);
  void highLiteCmd(Vector);
  void panToCmd(Vector);
  void panBeginCmd(Vector);
  void panMotionCmd(Vector);
  void panEndCmd(Vector);
  void setImageCompassCmd(int);
  void setWCSCompassCmd(int);
  void setBBoxCmd(int);
  void updateCmd(Pixmap);
  void updateBBoxCmd(BBox);
  void updateImageCompassCmd(Rotate);
  void updateWCSCompassCmd();
  void updateWCSCompassCmd(Vector,Vector);
  void warpCmd(Vector);
};

#endif

==> saods9_7.0.1+dfsg.orig.tar.gz: saods9/saotk/panner/panner.h <==
// Copyright (C) 1999-2012
// Smithsonian Astrophysical Observatory, Cambridge, MA, USA
// For conditions of distribution and use, see copyright notice in "copyright"

#ifndef __panner_h__
#define __panner_h__

#include "widget.h"

class Panner : public Widget {
 private:
  Pixmap thumbnail;          // current frame thumbnail pixmap
  int highLite;              // flag to highlite bbox
  int panning;               // flag for panning status
  Vector panStart;           // initial location of panning operation
  int needsUpdate;           // flag to indicate refresh needed

  GC bboxGC;                 // bbox gc
  int useBBox;               // flag to use BBox
  Vector bbox[4];            // current view

  GC compassGC;              // compass gc
  Vector imageX;
  Vector imageY;
  Vector imageZ;
  int threed;                // 2d or 3d compass
  int useCompass;            // flag to use image/wcs compass
  Vector wcsNorth;
  Vector wcsEast;
  int validWCSCompass;       // flag to indicate wcs data is valid

  int useFont;               // flag to use fonts
  Tk_Font tkfont_;              // Tk font
  Tk_FontMetrics metric;     // Tk font metric
				  
 private:
  void update();             // use existing pixmap, just update
  void invalidPixmap();      // new pixmap, then update

 protected:
  virtual void clearPixmap() =0;  // clear pixmap

 private:
  int updatePixmap(const BBox&); // renders image/graphics into pixmap
  void renderBBox();
  int isInBBox(const Vector&);
  void renderImageCompass();
  void renderWCSCompass();
  void renderArm(int, Vector, Rotate, const char*, int);
  void updateGCs();

 public:
  Panner(Tcl_Interp*, Tk_Canvas, Tk_Item*);
  virtual ~Panner();

  int parse(istringstream&);            // parse subcommands

  // SubCommandFunctions

  void getBBoxCmd();
  void getSizeCmd();
  void highLiteCmd(int);
  void highLiteCmd(const Vector&);
  void panToCmd(const Vector&);
  void panBeginCmd(const Vector&);
  void panMotionCmd(const Vector&);
  void panEndCmd(const Vector&);
  void setCompassCmd(int);
  void setBBoxCmd(int);
  void updateCmd(Pixmap);
  void updateBBoxCmd(const Vector&, const Vector&, 
		     const Vector&, const Vector&);
  void updateImageCompassCmd(Vector, Vector);
  void updateImageCompassCmd(Vector, Vector, Vector);
  void updateWCSCompassCmd();
  void updateWCSCompassCmd(const Vector&, const Vector&);
  void warpCmd(const Vector&);
};

#endif
